----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    14:06:39 07/13/2007 
-- Design Name: ADC Testing Box
-- Module Name:    ADC_box - ADC_box_arch 
-- Project Name: ADC Module
-- Target Devices: none; for testing and simulation only
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Testing box to run controller and emulator together
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity ADC_box is
    Port ( Clk : in  STD_LOGIC;
           iRst : in  STD_LOGIC;
           Go : in  STD_LOGIC;
           Wr : in  STD_LOGIC;
           A_in : in  STD_LOGIC_VECTOR (2 downto 0);
           Error : out  STD_LOGIC;
           A_out : out  STD_LOGIC_VECTOR (2 downto 0);
           D : out  STD_LOGIC_VECTOR (11 downto 0));
end ADC_box;

architecture ADC_box_arch of ADC_box is

	component controller is
		Port ( Clk : in  STD_LOGIC;
				 iRst_in : in  STD_LOGIC;
				 Go : in  STD_LOGIC;
				 Wr : in  STD_LOGIC;
				 A_in : in  STD_LOGIC_VECTOR (2 downto 0);
				 D_out : in  STD_LOGIC;
				 SCLK : out  STD_LOGIC;
				 iRst_out : out  STD_LOGIC;
				 iCS : out  STD_LOGIC;
				 D_in : out  STD_LOGIC;
				 A_out : out  STD_LOGIC_VECTOR (2 downto 0);
				 D : out  STD_LOGIC_VECTOR (11 downto 0));
	end component;
	
	component emulator is
		Port ( SCLK : in  STD_LOGIC;
				 iRst : in  STD_LOGIC;
				 iCS : in  STD_LOGIC;
				 D_in : in  STD_LOGIC;
				 ch0 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch1 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch2 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch3 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch4 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch5 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch6 : in  STD_LOGIC_VECTOR (11 downto 0);
				 ch7 : in  STD_LOGIC_VECTOR (11 downto 0);
				 D_out : out  STD_LOGIC;
				 Error : out  STD_LOGIC);
	end component;
	
	signal ch0 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch1 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch2 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch3 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch4 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch5 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch6 : STD_LOGIC_VECTOR (11 downto 0);
	signal ch7 : STD_LOGIC_VECTOR (11 downto 0);

	signal SCLK : STD_LOGIC;
	signal int_iRst : STD_LOGIC;
	signal iCS : STD_LOGIC;
	signal D_in : STD_LOGIC;
	signal D_out : STD_LOGIC;

begin

	ch0 <= "110000000111";
	ch1 <= "110000001011";
	ch2 <= "110000010011";
	ch3 <= "110000100011";
	ch4 <= "110001000011";
	ch5 <= "110010000011";
	ch6 <= "110100000011";
	ch7 <= "111000000011";

	u1: controller	port map (Clk, iRst, Go, Wr, A_in, D_out, SCLK, int_iRst, iCS, D_in, A_out, D);
	u2: emulator	port map (SCLK, int_iRst, iCS, D_in, ch0, ch1, ch2, ch3, ch4, ch5, ch6, ch7, D_out, Error);

end ADC_box_arch;

