----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    18:28:09 07/12/2007 
-- Design Name: Counter for ADC Controller
-- Module Name:    c_count - c_count_arch 
-- Project Name: ADC Module
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: A counter with asynchronous, active-low reset that marks off 17
--		cycles; from idle it counts 16 cycles during which iCS is low (iCS idles
--		high), then a single cycle return to idle state; the go line intiates a
--		counting cycle (leaves the idle state)
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity c_count is
    Port ( Clk : in  STD_LOGIC;
           iRst : in  STD_LOGIC;
           Go : in  STD_LOGIC;
           iCS : out  STD_LOGIC);
end c_count;

architecture c_count_arch of c_count is

	signal count : STD_LOGIC_VECTOR (4 downto 0);

begin

	counter : process (Clk, iRst, Go)
	begin
		if (iRst = '0') then
			count <= "10000";
		else
			if (rising_edge(Clk)) then
				if (count = "10000") then
					if (Go = '1') then
						count <= "00000";
					else
						count <= count;
					end if;
				else
					count <= count + 1;
				end if;
			else
				count <= count;
			end if;
		end if;
	end process counter;
	
	iCS <= count(4);

end c_count_arch;

