----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    18:05:49 07/12/2007 
-- Design Name: Shift-In Register for ADC Controller
-- Module Name:    c_shift_in15 - c_shift_in15_arch 
-- Project Name: ADC Module
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: 15-bit shift-in register with asynchronous reset and shift
--		enable; splits output into address and data; overshifts first bit (16
--		shifting cycles, 15 bits) to delete junk
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity c_shift_in15 is
    Port ( Clk : in  STD_LOGIC;
           iRst : in  STD_LOGIC;
           Sh : in  STD_LOGIC;
           D : in  STD_LOGIC;
           A : out  STD_LOGIC_VECTOR (2 downto 0);
           Q : out  STD_LOGIC_VECTOR (11 downto 0));
end c_shift_in15;

architecture c_shift_in15_arch of c_shift_in15 is

	signal reg : STD_LOGIC_VECTOR (14 downto 0);

begin

	shift : process (Clk, iRst, Sh)
	begin
		if (iRst = '0') then
			reg <= "000000000000000";
		else
			if (rising_edge(Clk)) then
				if (Sh = '1') then
					for i in 0 to 13 loop
						reg(i+1) <= reg(i);
					end loop;
					reg(0) <= D;
				else
					reg <= reg;
				end if;
			else
				reg <= reg;
			end if;
		end if;
	end process shift;
	
	A <= reg (14 downto 12);
	Q <= reg (11 downto 0);

end c_shift_in15_arch;

