----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    18:13:23 07/12/2007 
-- Design Name: Shift-Out Register for ADC Controller
-- Module Name:    c_shift_out12 - c_shift_out12_arch 
-- Project Name: ADC Module
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: 12-bit shift-out register with asynchronous, active-low reset and
--		shift/load toggle that loads preset values around the write bit and the
--		address bits; overshifts (16 shifting cycles, 12 bits) and drags zero to
--		pad end of bitstream
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity c_shift_out12 is
    Port ( Clk : in  STD_LOGIC;
           iRst : in  STD_LOGIC;
           Sh_Ld : in  STD_LOGIC;
           D_W : in  STD_LOGIC;
           D_A : in  STD_LOGIC_VECTOR (8 downto 6);
           Q : out  STD_LOGIC);
end c_shift_out12;

architecture c_shift_out12_arch of c_shift_out12 is

	signal reg : STD_LOGIC_VECTOR (11 downto 0);
	signal line : STD_LOGIC;

begin

	shift : process (CLK, iRst, Sh_Ld)
	begin
		if (iRst = '0') then
			reg <= "000000000000";
			line <= '0';
		else
			if (rising_edge(Clk)) then
				if (Sh_Ld = '1') then
					for i in 0 to 10 loop
						reg(i+1) <= reg(i);
					end loop;
					reg(0) <= '0';
					line <= reg(11);
				else
					reg(11) <= D_W;
					reg(10 downto 9) <= "00";
					reg(8 downto 6) <= D_A;
					reg(5 downto 0) <= "110000";
					line <= '0';
				end if;
			else
				reg <= reg;
				line <= line;
			end if;
		end if;
	end process shift;
	
	Q <= line;

end c_shift_out12_arch;

