----------------------------------------------------------------------------------
-- Company: University of Connecticut
-- Engineer: Brendan Krueger
-- 
-- Create Date:    09:52:59 07/13/2007 
-- Design Name: ADC Controller
-- Module Name:    controller - contr_arch 
-- Project Name: ADC Module
-- Target Devices: Xilinx Spartan-3A
-- Tool versions: Xilinx ISE WebPACK 9.1.03i
-- Description: Controller for ADC chip
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity controller is
    Port ( Clk : in  STD_LOGIC;
           iRst_in : in  STD_LOGIC;
           Go : in  STD_LOGIC;
           Wr : in  STD_LOGIC;
           A_in : in  STD_LOGIC_VECTOR (2 downto 0);
           D_out : in  STD_LOGIC;
           SCLK : out  STD_LOGIC;
           iRst_out : out  STD_LOGIC;
           iCS : out  STD_LOGIC;
           D_in : out  STD_LOGIC;
           A_out : out  STD_LOGIC_VECTOR (2 downto 0);
           D : out  STD_LOGIC_VECTOR (11 downto 0));
end controller;

architecture contr_arch of controller is

	component c_count is
		Port ( Clk : in  STD_LOGIC;
				 iRst : in  STD_LOGIC;
				 Go : in  STD_LOGIC;
				 iCS : out  STD_LOGIC);
	end component;
	
	component c_delay is
		Port ( Clk : in  STD_LOGIC;
				 D : in  STD_LOGIC;
				 Q : out  STD_LOGIC);
	end component;
	
	component c_shift_in15 is
		Port ( Clk : in  STD_LOGIC;
				 iRst : in  STD_LOGIC;
				 Sh : in  STD_LOGIC;
				 D : in  STD_LOGIC;
				 A : out  STD_LOGIC_VECTOR (2 downto 0);
				 Q : out  STD_LOGIC_VECTOR (11 downto 0));
	end component;
	
	component c_shift_out12 is
		Port ( Clk : in  STD_LOGIC;
				 iRst : in  STD_LOGIC;
				 Sh_Ld : in  STD_LOGIC;
				 D_W : in  STD_LOGIC;
				 D_A : in  STD_LOGIC_VECTOR (8 downto 6);
				 Q : out  STD_LOGIC);
	end component;

	signal int_iCS : STD_LOGIC;
	signal int_CS : STD_LOGIC;
	signal del_CS : STD_LOGIC;

begin

	int_CS <= not int_iCS;
	SCLK <= Clk;
	iRst_out <= iRst_in;

	u1: c_count			port map (Clk, iRst_in, Go, int_iCS);
	u2: c_delay			port map (Clk, int_iCS, iCS);
	u3: c_delay			port map (Clk, int_CS, del_CS);
	u4: c_shift_in15	port map (Clk, iRst_in, del_CS, D_out, A_out, D);
	u5: c_shift_out12	port map (Clk, iRst_in, int_CS, Wr, A_in, D_in);

end contr_arch;

